@@ -1,12 +1,15 @@
 """
 Various decorators used in pyFF.
 """
-__author__ = 'leifj'
+import functools
+import warnings
 
+__author__ = 'leifj'
 
 import time
 from pyff.logs import log
 
+
 def retry(ExceptionToCheck, tries=4, delay=3, backoff=2, logger=log):
     """Retry calling the decorated function using an exponential backoff.
 
@@ -26,6 +29,7 @@ def retry(ExceptionToCheck, tries=4, delay=3, backoff=2, logger=log):
     :param logger: logger to use. If None, print
     :type logger: logging.Logger instance
     """
+
     def deco_retry(f):
         def f_retry(*args, **kwargs):
             mtries, mdelay = tries, delay
@@ -47,5 +51,24 @@ def retry(ExceptionToCheck, tries=4, delay=3, backoff=2, logger=log):
             if try_one_last_time:
                 return f(*args, **kwargs)
             return
+
         return f_retry  # true decorator
-    return deco_retry
\ No newline at end of file
+
+    return deco_retry
+
+
+def deprecated(func):
+    """This is a decorator which can be used to mark functions
+    as deprecated. It will result in a warning being emitted
+    when the function is used."""
+
+    @functools.wraps(func)
+    def new_func(*args, **kwargs):
+        warnings.warn_explicit(
+            "Call to deprecated function {}.".format(func.__name__),
+            category=DeprecationWarning,
+            filename=func.func_code.co_filename,
+            lineno=func.func_code.co_firstlineno + 1
+        )
+        return func(*args, **kwargs)
+    return new_func
\ No newline at end of file
